.. pypi-sphinx-quickstart documentation master file, created by
   pypi-sphinx-quickstart.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to finstmt documentation!
*********************************************

To get started, look here.

.. toctree::
   :caption: Tutorial

   tutorial
   auto_examples/index

An overview
===========

Quick Links
------------

Find the source code `on Github <https://github.com/nickderobertis/py-finstmt>`_.


.. autosummarynameonly::

      finstmt.combined.statements.FinancialStatements
      finstmt.inc.main.IncomeStatements
      finstmt.bs.main.BalanceSheets


.. toctree:: api/modules
   :caption: API Documentation
   :maxdepth: 3

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
